# -*- coding: utf-8 -*-


class PayoutStatus:
    """
    Constants representing payout statuses. Available values are:
    """
    PENDING = 'pending'
    SUCCEEDED = 'succeeded'
    CANCELED = 'canceled'



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.models.confirmation.request.confirmation_embedded import \
    ConfirmationEmbedded as RequestConfirmationEmbedded
from yookassa.domain.models.confirmation.request.confirmation_external import \
    ConfirmationExternal as RequestConfirmationExternal
from yookassa.domain.models.confirmation.request.confirmation_qr import \
    ConfirmationQr as RequestConfirmationQr
from yookassa.domain.models.confirmation.request.confirmation_redirect import \
    ConfirmationRedirect as RequestConfirmationRedirect
from yookassa.domain.models.confirmation.request.confirmation_mobile_application import \
    ConfirmationMobileApplication as RequestConfirmationMobileApplication
from yookassa.domain.models.confirmation.response.confirmation_embedded import \
    ConfirmationEmbedded as ResponseConfirmationEmbedded
from yookassa.domain.models.confirmation.response.confirmation_external import \
    ConfirmationExternal as ResponseConfirmationExternal
from yookassa.domain.models.confirmation.response.confirmation_qr import \
    ConfirmationQr as ResponseConfirmationQr
from yookassa.domain.models.confirmation.response.confirmation_redirect import \
    ConfirmationRedirect as ResponseConfirmationRedirect
from yookassa.domain.models.confirmation.response.confirmation_mobile_application import \
    ConfirmationMobileApplication as ResponseConfirmationMobileApplication


class ConfirmationClassMap(DataContext):
    def __init__(self):
        super(ConfirmationClassMap, self).__init__(('request', 'response'))

    @property
    def request(self):
        return {
            ConfirmationType.REDIRECT: RequestConfirmationRedirect,
            ConfirmationType.EXTERNAL: RequestConfirmationExternal,
            ConfirmationType.EMBEDDED: RequestConfirmationEmbedded,
            ConfirmationType.QR: RequestConfirmationQr,
            ConfirmationType.MOBILE_APPLICATION: RequestConfirmationMobileApplication
        }

    @property
    def response(self):
        return {
            ConfirmationType.REDIRECT: ResponseConfirmationRedirect,
            ConfirmationType.EXTERNAL: ResponseConfirmationExternal,
            ConfirmationType.EMBEDDED: ResponseConfirmationEmbedded,
            ConfirmationType.QR: ResponseConfirmationQr,
            ConfirmationType.MOBILE_APPLICATION: ResponseConfirmationMobileApplication
        }



# -*- coding: utf-8 -*-
"""Top-level package for YooKassa API Python Client Library."""

from yookassa.domain.exceptions.api_error import ApiError
from yookassa.domain.exceptions.authorize_error import AuthorizeError
from yookassa.domain.exceptions.bad_request_error import BadRequestError
from yookassa.domain.exceptions.forbidden_error import ForbiddenError
from yookassa.domain.exceptions.not_found_error import NotFoundError
from yookassa.domain.exceptions.response_processing_error import ResponseProcessingError
from yookassa.domain.exceptions.too_many_request_error import TooManyRequestsError
from yookassa.domain.exceptions.unauthorized_error import UnauthorizedError



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import PaymentData


class PaymentDataApplepay(PaymentData):
    __payment_data = None

    def __init__(self, *args, **kwargs):
        super(PaymentDataApplepay, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.APPLEPAY:
            self.type = PaymentMethodType.APPLEPAY

    @property
    def payment_data(self):
        return self.__payment_data

    @payment_data.setter
    def payment_data(self, value):
        self.__payment_data = str(value)



# -*- coding: utf-8 -*-
import platform
import sys

import distro

import yookassa


class UserAgent:
    """
    """
    VERSION_DELIMITER = '/'
    PART_DELIMITER = ' '

    __os = None
    __python = None
    __framework = None
    __cms = None
    __module = None
    __sdk = None

    def __init__(self):
        self.os = self.define_os()
        self.python = self.define_python()
        self.sdk = self.define_sdk()

    def define_os(self):
        simple = self.__define_simple_os()
        if simple.name == 'Windows':
            return Version(simple.name, simple.version)
        elif simple.name == 'Linux':
            smart = self.__define_linux_os()
            return Version(smart.name.capitalize(), smart.version)
        else:
            return Version(simple.name, simple.version)

    @staticmethod
    def define_python():
        info = sys.version_info
        version = str(info.major) + '.' + str(info.minor) + '.' + str(info.micro)
        return Version('Python', version)

    @staticmethod
    def define_sdk():
        version = yookassa.__version__
        return Version('YooKassa.Python', version)

    @property
    def os(self):
        return self.__os

    @os.setter
    def os(self, value):
        self.__os = str(value)

    @property
    def python(self):
        return self.__python

    @python.setter
    def python(self, value):
        self.__python = str(value)

    @property
    def framework(self):
        return self.__framework

    @framework.setter
    def framework(self, value):
        self.__framework = str(value)

    @property
    def cms(self):
        return self.__cms

    @cms.setter
    def cms(self, value):
        self.__cms = str(value)

    @property
    def module(self):
        return self.__module

    @module.setter
    def module(self, value):
        self.__module = str(value)

    @property
    def sdk(self):
        return self.__sdk

    @sdk.setter
    def sdk(self, value):
        self.__sdk = str(value)

    def set_framework(self, name, version):
        self.framework = Version(name, version)
        return self

    def set_cms(self, name, version):
        self.cms = Version(name, version)
        return self

    def set_module(self, name, version):
        self.module = Version(name, version)
        return self

    def get_header_string(self):
        headers = [str(self.os), str(self.python)]
        if self.framework is not None:
            headers.append(str(self.framework))
        if self.cms is not None:
            headers.append(str(self.cms))
        if self.module is not None:
            headers.append(str(self.module))
        headers.append(str(self.sdk))

        return self.PART_DELIMITER.join(headers)

    @staticmethod
    def __define_simple_os():
        return Version(platform.system(), platform.release())

    @staticmethod
    def __define_linux_os():
        dist = distro.linux_distribution(full_distribution_name=False)
        os = Version(dist[0], dist[1])
        return os

    @staticmethod
    def create_version(name, version):
        strip_data = ' ' + UserAgent.PART_DELIMITER + UserAgent.VERSION_DELIMITER
        return name.strip(strip_data).replace(UserAgent.PART_DELIMITER, '.').replace(UserAgent.VERSION_DELIMITER, '.') \
               + UserAgent.VERSION_DELIMITER \
               + version.strip(strip_data).replace(UserAgent.PART_DELIMITER, '.').replace(UserAgent.VERSION_DELIMITER, '.')


class Version:
    __name = None
    __version = None

    def __init__(self, name, version):
        self.name = name
        self.version = version

    @property
    def name(self):
        return self.__name

    @name.setter
    def name(self, value):
        self.__name = str(value)

    @property
    def version(self):
        return self.__version

    @version.setter
    def version(self, value):
        self.__version = str(value)

    def __str__(self):
        return UserAgent.create_version(self.name, self.version)



# -*- coding: utf-8 -*-
from yookassa.domain.common import ResponseObject
from yookassa.domain.models import Amount


class DealResponse(ResponseObject):
    """
    Class representing response object.

    Contains data
    """
    __id = None

    __type = None

    __status = None

    __balance = None

    __payout_balance = None

    __description = None

    __fee_moment = None

    __created_at = None

    __expires_at = None

    __test = None

    __metadata = None

    @property
    def id(self):
        return self.__id

    @id.setter
    def id(self, value):
        self.__id = value

    @property
    def status(self):
        return self.__status

    @status.setter
    def status(self, value):
        self.__status = value

    @property
    def balance(self):
        return self.__balance

    @balance.setter
    def balance(self, value):
        self.__balance = Amount(value)

    @property
    def payout_balance(self):
        return self.__payout_balance

    @payout_balance.setter
    def payout_balance(self, value):
        self.__payout_balance = Amount(value)

    @property
    def description(self):
        return self.__description

    @description.setter
    def description(self, value):
        self.__description = value

    @property
    def fee_moment(self):
        return self.__fee_moment

    @fee_moment.setter
    def fee_moment(self, value):
        self.__fee_moment = str(value)

    @property
    def created_at(self):
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        self.__created_at = value

    @property
    def expires_at(self):
        return self.__expires_at

    @expires_at.setter
    def expires_at(self, value):
        self.__expires_at = value

    @property
    def test(self):
        return self.__test

    @test.setter
    def test(self, value):
        self.__test = bool(value)

    @property
    def metadata(self):
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        self.__metadata = value



# -*- coding: utf-8 -*-

from yookassa.domain.common import BaseObject


class ReceiptItemSupplier(BaseObject):
    """
    Class representing receipt item supplier data wrapper object

    Used in Receipt
    """
    __name = None

    __inn = None

    __phone = None

    @property
    def name(self):
        return self.__name

    @name.setter
    def name(self, value):
        self.__name = str(value)

    @property
    def inn(self):
        return self.__inn

    @inn.setter
    def inn(self, value):
        self.__inn = str(value)

    @property
    def phone(self):
        return self.__phone

    @phone.setter
    def phone(self, value):
        self.__phone = str(value)




# -*- coding: utf-8 -*-
import uuid

from yookassa.client import ApiClient
from yookassa.domain.common.http_verb import HttpVerb
from yookassa.domain.request import DealRequest
from yookassa.domain.response import DealResponse, DealListResponse


class Deal:
    base_path = '/deals'

    def __init__(self):
        self.client = ApiClient()

    @classmethod
    def find_one(cls, deal_id):
        """
        Get receipt information

        :param deal_id:
        :return: DealResponse
        """
        instance = cls()
        if not isinstance(deal_id, str) or not deal_id:
            raise ValueError('Invalid payment_id value')

        path = instance.base_path + '/' + deal_id
        response = instance.client.request(HttpVerb.GET, path)
        return DealResponse(response)

    @classmethod
    def create(cls, params, idempotency_key=None):
        """
        Create receipt

        :param params: data passed to API
        :param idempotency_key:
        :return: DealResponse
        """
        instance = cls()
        path = cls.base_path

        if not idempotency_key:
            idempotency_key = uuid.uuid4()

        headers = {
            'Idempotence-Key': str(idempotency_key)
        }

        if isinstance(params, dict):
            params_object = DealRequest(params)
        elif isinstance(params, DealRequest):
            params_object = params
        else:
            raise TypeError('Invalid params value type')

        response = instance.client.request(HttpVerb.POST, path, None, headers, params_object)
        return DealResponse(response)

    @classmethod
    def list(cls, params):
        instance = cls()
        path = cls.base_path

        response = instance.client.request(HttpVerb.GET, path, params)
        return DealListResponse(response)



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class ReceiptCustomer(BaseObject):
    """
    Class representing receipt customer data wrapper object

    Used in Receipt
    """
    __full_name = None

    __inn = None

    __email = None

    __phone = None

    @property
    def full_name(self):
        return self.__full_name

    @full_name.setter
    def full_name(self, value):
        self.__full_name = str(value)

    @property
    def inn(self):
        return self.__inn

    @inn.setter
    def inn(self, value):
        self.__inn = str(value)

    @property
    def email(self):
        return self.__email

    @email.setter
    def email(self, value):
        cast_value = str(value)
        if re.match(r"^[^@]+@[^@]+\.[^@]+$", cast_value):
            self.__email = cast_value
        else:
            raise ValueError('Invalid email value type')

    @property
    def phone(self):
        return self.__phone

    @phone.setter
    def phone(self, value):
        self.__phone = str(value)




# -*- coding: utf-8 -*-


class ConfirmationType:
    """
    Constants representing confirmation types. Available values are:

    * yookassa.domain.common.ConfirmationType.EXTERNAL
    * yookassa.domain.common.ConfirmationType.REDIRECT
    * yookassa.domain.common.ConfirmationType.EMBEDDED
    * yookassa.domain.common.ConfirmationType.QR
    * yookassa.domain.common.ConfirmationType.MOBILE_APPLICATION
    """
    EMBEDDED = 'embedded'
    EXTERNAL = 'external'
    REDIRECT = 'redirect'
    QR = 'qr'
    MOBILE_APPLICATION = 'mobile_application'



# -*- coding: utf-8 -*-
from yookassa.domain.common import ResponseObject
from yookassa.domain.models import Amount, CancellationDetails
from yookassa.domain.models.deal import PayoutDealInfo
from yookassa.domain.models.payout_data.payout_destination_factory import PayoutDestinationFactory


class PayoutResponse(ResponseObject):
    """
    Class representing response object.

    Contains data
    """
    __id = None

    __amount = None

    __status = None

    __payout_destination = None

    __description = None

    __created_at = None

    __deal = None

    __cancellation_details = None

    __metadata = None

    __test = None

    @property
    def id(self):
        return self.__id

    @id.setter
    def id(self, value):
        self.__id = value

    @property
    def amount(self):
        return self.__amount

    @amount.setter
    def amount(self, value):
        self.__amount = Amount(value)

    @property
    def status(self):
        return self.__status

    @status.setter
    def status(self, value):
        self.__status = value

    @property
    def payout_destination(self):
        return self.__payout_destination

    @payout_destination.setter
    def payout_destination(self, value):
        self.__payout_destination = PayoutDestinationFactory().create(value, self.context())

    @property
    def description(self):
        return self.__description

    @description.setter
    def description(self, value):
        self.__description = value

    @property
    def created_at(self):
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        self.__created_at = value

    @property
    def deal(self):
        return self.__deal

    @deal.setter
    def deal(self, value):
        self.__deal = PayoutDealInfo(value)

    @property
    def cancellation_details(self):
        return self.__cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, value):
        self.__cancellation_details = CancellationDetails(value)

    @property
    def metadata(self):
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        self.__metadata = value

    @property
    def test(self):
        return self.__test

    @test.setter
    def test(self, value):
        self.__test = bool(value)



# -*- coding: utf-8 -*-


class ReceiptType:
    """
    Constants representing receipt types. Available values are:
    """
    PAYMENT = 'payment'
    REFUND = 'refund'


class ReceiptItemAgentType:
    """
    Constants representing receipt item agent types. Available values are:
    """
    BANKING_PAYMENT_AGENT = 'banking_payment_agent'
    BANKING_PAYMENT_SUBAGENT = 'banking_payment_subagent'
    PAYMENT_AGENT = 'payment_agent'
    PAYMENT_SUBAGENT = 'payment_subagent'
    ATTORNEY = 'attorney'
    COMMISSIONER = 'commissioner'
    AGENT = 'agent'



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class CreditCard(BaseObject):

    __number = None

    @property
    def number(self):
        return self.__number

    @number.setter
    def number(self, value):
        cast_value = str(value)
        if re.match(r'^[0-9]{12,19}$', cast_value):
            self.__number = cast_value
        else:
            raise ValueError('Invalid card number value')



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount


class Settlement(BaseObject):
    """
    Class representing receipt settlement data wrapper object

    Used in Receipt
    """
    __type = None

    __amount = None

    @property
    def type(self):
        return self.__type

    @type.setter
    def type(self, value):
        self.__type = str(value)

    @property
    def amount(self):
        return self.__amount

    @amount.setter
    def amount(self, value):
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')


class SettlementType(object):
    """
    Class representing SettlementType values enum
    """
    CASHLESS = 'cashless'
    PREPAYMENT = 'prepayment'
    POSTPAYMENT = 'postpayment'
    CONSIDERATION = 'consideration'


class SettlementPayoutType(object):
    """
    Class representing SettlementPayoutType values enum
    """
    PAYOUT = 'payout'



# -*- coding: utf-8 -*-
from yookassa.domain.common.user_agent import Version


class ConfigurationError(Exception):
    pass


class Configuration(object):
    """
    A class representing the configuration.
    """
    api_url = "https://api.yookassa.ru/v3"
    account_id = None
    secret_key = None
    timeout = 1800
    max_attempts = 3
    auth_token = None
    agent_framework = None
    agent_cms = None
    agent_module = None

    def __init__(self, **kwargs):
        self.assert_has_api_credentials()

    @staticmethod
    def configure(account_id, secret_key, **kwargs):
        Configuration.account_id = account_id
        Configuration.secret_key = secret_key
        Configuration.auth_token = None
        Configuration.timeout = kwargs.get("timeout", 1800)
        Configuration.max_attempts = kwargs.get("max_attempts", 3)

    @staticmethod
    def configure_auth_token(token, **kwargs):
        Configuration.account_id = None
        Configuration.secret_key = None
        Configuration.auth_token = token
        Configuration.timeout = kwargs.get("timeout", 1800)
        Configuration.max_attempts = kwargs.get("max_attempts", 3)

    @staticmethod
    def configure_user_agent(framework=None, cms=None, module=None):
        if isinstance(framework, Version):
            Configuration.agent_framework = framework
        if isinstance(cms, Version):
            Configuration.agent_cms = cms
        if isinstance(module, Version):
            Configuration.agent_module = module

    @staticmethod
    def instantiate():
        return Configuration(
            shop_id=Configuration.account_id,
            shop_password=Configuration.secret_key,
            timeout=Configuration.timeout,
            max_attempts=Configuration.max_attempts,
            auth_token=Configuration.auth_token,
            agent_framework=Configuration.agent_framework,
            agent_cms=Configuration.agent_cms,
            agent_module=Configuration.agent_module
        )

    @staticmethod
    def api_endpoint():
        return Configuration.api_url

    def has_api_credentials(self):
        return self.account_id is not None and self.secret_key is not None

    def assert_has_api_credentials(self):
        if self.auth_token is None and not self.has_api_credentials():
            raise ConfigurationError("account_id and secret_key are required")
        elif self.auth_token and self.has_api_credentials():
            raise ConfigurationError("Could not configure authorization with auth_token and basic auth")



# -*- coding: utf-8 -*-
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.request.payment_data_alfabank import \
    PaymentDataAlfabank as RequestPaymentDataAlfabank
from yookassa.domain.models.payment_data.request.payment_data_applepay import \
    PaymentDataApplepay as RequestPaymentDataApplepay
from yookassa.domain.models.payment_data.request.payment_data_b2b_sberbank import \
    PaymentDataB2bSberbank as RequestPaymentDataB2bSberbank
from yookassa.domain.models.payment_data.request.payment_data_bank_card import \
    PaymentDataBankCard as RequestPaymentDataBankCard
from yookassa.domain.models.payment_data.request.payment_data_cash import \
    PaymentDataCash as RequestPaymentDataCash
from yookassa.domain.models.payment_data.request.payment_data_google_pay import \
    PaymentDataGooglePay as RequestPaymentDataGooglePay
from yookassa.domain.models.payment_data.request.payment_data_installments import \
    PaymentDataInstallments as RequestPaymentDataInstallments
from yookassa.domain.models.payment_data.request.payment_data_mobile_balance import \
    PaymentDataMobileBalance as RequestPaymentDataMobileBalance
from yookassa.domain.models.payment_data.request.payment_data_qiwi import \
    PaymentDataQiwi as RequestPaymentDataQiwi
from yookassa.domain.models.payment_data.request.payment_data_sberbank import \
    PaymentDataSberbank as RequestPaymentDataSberbank
from yookassa.domain.models.payment_data.request.payment_data_tinkoff_bank import \
    PaymentDataTinkoffBank as RequestPaymentDataTinkoffBank
from yookassa.domain.models.payment_data.request.payment_data_webmoney import \
    PaymentDataWebmoney as RequestPaymentDataWebmoney
from yookassa.domain.models.payment_data.request.payment_data_wechat import \
    PaymentDataWechat as RequestPaymentDataWechat
from yookassa.domain.models.payment_data.request.payment_data_yoomoney_wallet import \
    PaymentDataYooMoneyWallet as RequestPaymentDataYooMoneyWallet
from yookassa.domain.models.payment_data.response.payment_data_alfabank import \
    PaymentDataAlfabank as ResponsePaymentDataAlfabank
from yookassa.domain.models.payment_data.response.payment_data_applepay import \
    PaymentDataApplepay as ResponsePaymentDataApplepay
from yookassa.domain.models.payment_data.response.payment_data_b2b_sberbank import \
    PaymentDataB2bSberbank as ResponsePaymentDataB2bSberbank
from yookassa.domain.models.payment_data.response.payment_data_bank_card import \
    PaymentDataBankCard as ResponsePaymentDataBankCard
from yookassa.domain.models.payment_data.response.payment_data_cash import \
    PaymentDataCash as ResponsePaymentDataCash
from yookassa.domain.models.payment_data.response.payment_data_google_pay import \
    PaymentDataGooglePay as ResponsePaymentDataGooglePay
from yookassa.domain.models.payment_data.response.payment_data_installments import \
    PaymentDataInstallments as ResponsePaymentDataInstallments
from yookassa.domain.models.payment_data.response.payment_data_mobile_balance import \
    PaymentDataMobileBalance as ResponsePaymentDataMobileBalance
from yookassa.domain.models.payment_data.response.payment_data_psb import \
    PaymentDataPsb as ResponsePaymentDataPsb
from yookassa.domain.models.payment_data.response.payment_data_qiwi import \
    PaymentDataQiwi as ResponsePaymentDataQiwi
from yookassa.domain.models.payment_data.response.payment_data_sberbank import \
    PaymentDataSberbank as ResponsePaymentDataSberbank
from yookassa.domain.models.payment_data.response.payment_data_tinkoff_bank import \
    PaymentDataTinkoffBank as ResponsePaymentDataTinkoffBank
from yookassa.domain.models.payment_data.response.payment_data_webmoney import \
    PaymentDataWebmoney as ResponsePaymentDataWebmoney
from yookassa.domain.models.payment_data.response.payment_data_wechat import \
    PaymentDataWechat as ResponsePaymentDataWechat
from yookassa.domain.models.payment_data.response.payment_data_yoomoney_wallet import \
    PaymentDataYooMoneyWallet as ResponsePaymentDataYooMoneyWallet


class PaymentDataClassMap(DataContext):
    def __init__(self):
        super(PaymentDataClassMap, self).__init__(('request', 'response'))

    @property
    def request(self):
        return {
            PaymentMethodType.ALFABANK: RequestPaymentDataAlfabank,
            PaymentMethodType.BANK_CARD: RequestPaymentDataBankCard,
            PaymentMethodType.CASH: RequestPaymentDataCash,
            PaymentMethodType.MOBILE_BALANCE: RequestPaymentDataMobileBalance,
            PaymentMethodType.SBERBANK: RequestPaymentDataSberbank,
            PaymentMethodType.YOO_MONEY: RequestPaymentDataYooMoneyWallet,
            PaymentMethodType.QIWI: RequestPaymentDataQiwi,
            PaymentMethodType.WEBMONEY: RequestPaymentDataWebmoney,
            PaymentMethodType.APPLEPAY: RequestPaymentDataApplepay,
            PaymentMethodType.GOOGLE_PAY: RequestPaymentDataGooglePay,
            PaymentMethodType.INSTALMENTS: RequestPaymentDataInstallments,
            PaymentMethodType.B2B_SBERBANK: RequestPaymentDataB2bSberbank,
            PaymentMethodType.TINKOFF_BANK: RequestPaymentDataTinkoffBank,
            PaymentMethodType.WECHAT: RequestPaymentDataWechat,
        }

    @property
    def response(self):
        return {
            PaymentMethodType.ALFABANK: ResponsePaymentDataAlfabank,
            PaymentMethodType.BANK_CARD: ResponsePaymentDataBankCard,
            PaymentMethodType.CASH: ResponsePaymentDataCash,
            PaymentMethodType.MOBILE_BALANCE: ResponsePaymentDataMobileBalance,
            PaymentMethodType.SBERBANK: ResponsePaymentDataSberbank,
            PaymentMethodType.YOO_MONEY: ResponsePaymentDataYooMoneyWallet,
            PaymentMethodType.PSB: ResponsePaymentDataPsb,
            PaymentMethodType.QIWI: ResponsePaymentDataQiwi,
            PaymentMethodType.WEBMONEY: ResponsePaymentDataWebmoney,
            PaymentMethodType.APPLEPAY: ResponsePaymentDataApplepay,
            PaymentMethodType.GOOGLE_PAY: ResponsePaymentDataGooglePay,
            PaymentMethodType.INSTALMENTS: ResponsePaymentDataInstallments,
            PaymentMethodType.B2B_SBERBANK: ResponsePaymentDataB2bSberbank,
            PaymentMethodType.TINKOFF_BANK: ResponsePaymentDataTinkoffBank,
            PaymentMethodType.WECHAT: ResponsePaymentDataWechat,
        }



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class CancellationDetails(BaseObject):
    """
    Class representing cancellation details data wrapper object
    """
    __party = None

    __reason = None

    @property
    def party(self):
        return self.__party

    @party.setter
    def party(self, value):
        self.__party = str(value)

    @property
    def reason(self):
        return self.__reason

    @reason.setter
    def reason(self, value):
        self.__reason = str(value)


class CancellationDetailsPartyCode(object):
    MERCHANT = 'merchant'
    YOO_KASSA = 'yoo_kassa'
    PAYMENT_NETWORK = 'payment_network'


class CancellationDetailsReasonCode(object):
    THREE_D_SECURE_FAILED = '3d_secure_failed'
    CALL_ISSUER = 'call_issuer'
    CARD_EXPIRED = 'card_expired'
    COUNTRY_FORBIDDEN = 'country_forbidden'
    FRAUD_SUSPECTED = 'fraud_suspected'
    GENERAL_DECLINE = 'general_decline'
    IDENTIFICATION_REQUIRED = 'identification_required'
    INSUFFICIENT_FUNDS = 'insufficient_funds'
    INVALID_CARD_NUMBER = 'invalid_card_number'
    INVALID_CSC = 'invalid_csc'
    ISSUER_UNAVAILABLE = 'issuer_unavailable'
    PAYMENT_METHOD_LIMIT_EXCEEDED = 'payment_method_limit_exceeded'
    PAYMENT_METHOD_RESTRICTED = 'payment_method_restricted'
    PERMISSION_REVOKED = 'permission_revoked'
    INTERNAL_TIMEOUT = 'internal_timeout'
    CANCELED_BY_MERCHANT = 'canceled_by_merchant'
    PAYMENT_EXPIRED = 'payment_expired'
    EXPIRED_ON_CONFIRMATION = 'expired_on_confirmation'
    EXPIRED_ON_CAPTURE = 'expired_on_capture'


class PayoutCancellationDetailsReasonCode(object):
    FRAUD_SUSPECTED = 'fraud_suspected'
    GENERAL_DECLINE = 'general_decline'
    ONE_TIME_LIMIT_EXCEEDED = 'one_time_limit_exceeded'
    PERIODIC_LIMIT_EXCEEDED = 'periodic_limit_exceeded'
    REJECTED_BY_PAYEE = 'rejected_by_payee'



# -*- coding: utf-8 -*-


class CardType:
    """
    Class representing credit cards available types enum
    """
    MASTER_CARD = 'MasterCard'
    VISA = 'Visa'
    MIR = 'MIR'
    UNION_PAY = 'UnionPay'
    CUP = 'CUP'
    JCB = 'JCB'
    AMERICAN_EXPRESS = 'AmericanExpress'
    DINERS_CLUB = 'DinersClub'
    UNKNOWN = 'Unknown'


class CardSource:
    """
    Class representing enum of available sources of credit cards
    """
    APPLE_PAY = 'apple_pay'
    GOOGLE_PAY = 'google_pay'
